# Pahelee

Maze generator using recursive depth first search algorithm

[![Demo](https://i.imgur.com/gy9hrI2.gif)](https://github.com/psuzn/pahelee)

## What is it?

**Pahelle** is a maze generator which impliments [Depth-first search Recursive backtracker](https://en.wikipedia.org/wiki/Maze_generation_algorithm) in OpenGL (python)

Installation / Usage
--------------------
**Installation**

To install use pip:

    $ pip install pahelee


Or clone the repo:

    $ git clone https://github.com/psuzn/pahelee.git
    $ python setup.py install

**Usage**

just run 
```shell
$ pahelee 
```
This will open a GLUT window of size 60*60 with 15 row and 15 columns (grid size) and after completition it will save a png image in your home directory.


## Todos

- [x] basic implimentation of algorithm.
- [x] Upload this pakage to PyPI.
- [ ] commandline arguments for different variables (like: no of grid rows).
## Support
This is in  alpha version and might cause some problem. so you can help me make it stable.


Please [open an issue](https://github.com/pahelee/romoNepali/issues/new) for support.

## Contributing

Please contribute using [Github Flow](https://guides.github.com/introduction/flow/). Create a branch, add commits, and [open a pull request](https://github.com/psuzn/pahelee/compare/).
